@@ -95,6 +95,13 @@ class stdcomPyQt(QObject):
             else:
                 self.sigNewData.emit(Name, Data)
 
+    def writeDescription(self,name, desc : str):
+        if desc is not None :
+            self.cBridge.UpdateDescription(name,desc)
+            self.liveDesc.update({name: desc})
+            self.sigNewDesc.emit(name, desc)
+
+
     def subscribe(self, Name: str):
         """
         Subscribe to a give Name
@@ -106,7 +113,7 @@ class stdcomPyQt(QObject):
             if self.cBridge is not None:
                 self.cBridge.AddSubscriptions([Name])
 
-    def getPossibleSubscribesr(self):
+    def getPossibleSubscribers(self):
         """
         All the possible subscription names possible
            :return: list of names of all possible subscritions
